YARP 2.3.20.1 (2012-12-19)                                          {#v2_3_20_1}
==========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.20...v2.3.20.1`):

```
     3	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
```
